import os

from qgis.core import QgsVectorLayer

from .. import (
    DATA_PATH,
    EXPECTED_PATH,
    OUTPUT_PATH,
    OVERWRITE_EXPECTED,
)
from ..utils import save_as_gml
from . import TestCase

PROJECT_PATH = os.path.join(DATA_PATH, "input", "Projection_points_traces")
TARGET_PROFILES_PATH = os.path.join(PROJECT_PATH, "profiles.geojson")
SOURCE_POINTS_PATH = os.path.join(PROJECT_PATH, "joined_points.geojson")


class TestImportLayerFromPointsAlgorithm(TestCase):

    ALGORITHM_ID = "precourlis:import_layer_from_points"
    DEFAULT_PARAMS = {
        "TARGET_LAYER_NAME": "zfond",
        "SOURCE_POINTS": SOURCE_POINTS_PATH,
        "SOURCE_FIELD_SEC_NAME": "Name",
        "SOURCE_FIELD_Z": "ELEVATION",
    }

    def test_import_layer_from_points(self):
        layer = QgsVectorLayer(TARGET_PROFILES_PATH)

        self.check_algorithm({"TARGET_PROFILES": layer})

        # Copy temporary layer to output
        expected = os.path.join(EXPECTED_PATH, "import_layer_from_points.gml")
        if OVERWRITE_EXPECTED:
            output = expected
        else:
            output = os.path.join(OUTPUT_PATH, "import_layer_from_points.gml")
        save_as_gml(layer, output)

        self.compare_layers(output, expected)
